@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3;
 
 #
-# $Id: NSEC3.pm 1362 2015-06-23 08:47:14Z willem $
+# $Id: NSEC3.pm 1367 2015-06-29 08:53:56Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1362 $)[1];
+$VERSION = (qw$LastChangedRevision: 1367 $)[1];
 
 
 use strict;
@@ -232,17 +232,17 @@ sub nxtdname { }			## inherited method inapplicable
 sub name2hash {
 	my $hashalg    = shift;
 	my $name       = shift;
-	my $iterations = shift || 0;
+	my $iterations = shift;
 	my $salt       = shift || '';
 
-	my $arglist = $digest{$hashalg} || die 'unsupported hash algorithm';
+	my $arglist = $digest{$hashalg};
 	my ( $object, @argument ) = @$arglist;
 	my $hash = $object->new(@argument);
 
 	my $wirename = new Net::DNS::DomainName2535($name)->encode;
 	$iterations++;
 
-	while ( $iterations-- > 0 ) {
+	while ( $iterations-- ) {
 		$hash->add($wirename);
 		$hash->add($salt);
 		$wirename = $hash->digest;
